==> haskell-validity-0.11.0.0-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validity
version:              0.11.0.0
visibility:           public
id:                   validity-0.11.0.0-z8bZ3KaaDV6TCXcpLy4D6
key:                  validity-0.11.0.0-z8bZ3KaaDV6TCXcpLy4D6
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity typeclass
description:
    For more info, see <https://github.com/NorfairKing/validity the readme>.

    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/validity-aeson validity-aeson>

    * <https://hackage.haskell.org/package/validity-bytestring validity-bytestring>

    * <https://hackage.haskell.org/package/validity-containers validity-containers>

    * <https://hackage.haskell.org/package/validity-path validity-path>

    * <https://hackage.haskell.org/package/validity-scientific validity-scientific>

    * <https://hackage.haskell.org/package/validity-text validity-text>

    * <https://hackage.haskell.org/package/validity-time validity-time>

    * <https://hackage.haskell.org/package/validity-unordered-containers validity-unordered-containers>

    * <https://hackage.haskell.org/package/validity-uuid validity-uuid>

    * <https://hackage.haskell.org/package/validity-vector validity-vector>

category:             Validity
abi:                  44fc23873d404e9c338ab943c0abac9c
exposed:              True
exposed-modules:      Data.RelativeValidity Data.Validity
hidden-modules:       Paths_validity
import-dirs:          /usr/lib/ghc-8.10.4/site-local/validity-0.11.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/validity-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/validity-0.11.0.0
hs-libraries:         HSvalidity-0.11.0.0-z8bZ3KaaDV6TCXcpLy4D6
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-validity/html/validity.haddock
haddock-html:         /usr/share/doc/haskell-validity/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-validity-0.11.0.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-validity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validity
version:              0.11.0.0
visibility:           public
id:                   validity-0.11.0.0-7kDXOAKQaI78QjzjAngqNE
key:                  validity-0.11.0.0-7kDXOAKQaI78QjzjAngqNE
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity typeclass
description:
    For more info, see <https://github.com/NorfairKing/validity the readme>.

    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/validity-aeson validity-aeson>

    * <https://hackage.haskell.org/package/validity-bytestring validity-bytestring>

    * <https://hackage.haskell.org/package/validity-containers validity-containers>

    * <https://hackage.haskell.org/package/validity-path validity-path>

    * <https://hackage.haskell.org/package/validity-scientific validity-scientific>

    * <https://hackage.haskell.org/package/validity-text validity-text>

    * <https://hackage.haskell.org/package/validity-time validity-time>

    * <https://hackage.haskell.org/package/validity-unordered-containers validity-unordered-containers>

    * <https://hackage.haskell.org/package/validity-uuid validity-uuid>

    * <https://hackage.haskell.org/package/validity-vector validity-vector>

category:             Validity
abi:                  316baab6fd6b0ca3496ec06d32fbe4af
exposed:              True
exposed-modules:      Data.RelativeValidity Data.Validity
hidden-modules:       Paths_validity
import-dirs:          /usr/lib/ghc-8.10.4/site-local/validity-0.11.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/validity-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/validity-0.11.0.0
hs-libraries:         HSvalidity-0.11.0.0-7kDXOAKQaI78QjzjAngqNE
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-validity/html/validity.haddock
haddock-html:         /usr/share/doc/haskell-validity/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
